################################################################
:mod:`.legend <highcharts_core.options.legend>`
################################################################

.. contents:: Module Contents
  :local:
  :depth: 3
  :backlinks: entry

.. toctree::
  :titlesonly:

  accessibility
  bubble_legend
  navigation
  title

-------------------------

.. module:: highcharts_core.options.legend

********************************************************************************************************************
class: :class:`Legend <highcharts_core.options.legend.Legend>`
********************************************************************************************************************

.. autoclass:: Legend
  :members:
  :inherited-members:

  .. collapse:: Class Inheritance

    .. inheritance-diagram:: Legend
      :top-classes: highcharts_core.metaclasses.HighchartsMeta
      :parts: -1

  |

-------------------------

***************************
Sub-components
***************************

.. list-table::
  :widths: 60 40
  :header-rows: 1

  * - Module
    - Classes / Functions
  * - :mod:`.options.legend <highcharts_core.options.legend>`
    - :class:`Legend <highcharts_core.options.legend.Legend>`
  * - :mod:`.options.legend.accessibility <highcharts_core.options.legend.accessibility>`
    - :class:`LegendAccessibilityOptions <highcharts_core.options.legend.accessibility.LegendAccessibilityOptions>`
      :class:`LegendKeyboardNavigation <highcharts_core.options.legend.accessibility.LegendKeyboardNavigation>`
  * - :mod:`.options.legend.bubble_legend <highcharts_core.options.legend.bubble_legend>`
    - :class:`BubbleLegend <highcharts_core.options.legend.bubble_legend.BubbleLegend>`
      :class:`BubbleLegendRange <highcharts_core.options.legend.bubble_legend.BubbleLegendRange>`
      :class:`BubbleLegendLabelOptions <highcharts_core.options.legend.bubble_legend.BubbleLegendLabelOptions>`
  * - :mod:`.options.legend.navigation <highcharts_core.options.legend.navigation>`
    - :class:`LegendNavigation <highcharts_core.options.legend.navigation.LegendNavigation>`
  * - :mod:`.options.legend.title <highcharts_core.options.legend.title>`
    - :class:`LegendTitle <highcharts_core.options.legend.title.LegendTitle>`
  * - :mod:`.options.loading <highcharts_core.options.loading>`
    - :class:`Loading <highcharts_core.options.loading.Loading>`
